==> jc-1.4.0.tar.gz: java/awt/dnd/DnDEventMulticaster.h <==
// class java.awt.dnd.DnDEventMulticaster

// class file dependencies
// @dep_class 36cab3420c6eb6e6 java_awt_AWTEventMulticaster
// @dep_class 4d3f307f23762559 java_awt_dnd_DnDEventMulticaster
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_AWTEventMulticaster

#include "java/awt/AWTEventMulticaster.h"

#ifndef _JC_java_awt_dnd_DnDEventMulticaster_H_
#define _JC_java_awt_dnd_DnDEventMulticaster_H_

// Forward structure declarations
struct _jc_java_awt_dnd_DragSourceListener$object;
struct _jc_java_awt_dnd_DragSourceMotionListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_EventListener$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DnDEventMulticaster$sub_refs	_jc_java_awt_dnd_DnDEventMulticaster$sub_refs;
typedef struct _jc_java_awt_dnd_DnDEventMulticaster$sub_nonrefs	_jc_java_awt_dnd_DnDEventMulticaster$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DnDEventMulticaster$refs	_jc_java_awt_dnd_DnDEventMulticaster$refs;
typedef struct _jc_java_awt_dnd_DnDEventMulticaster$nonrefs	_jc_java_awt_dnd_DnDEventMulticaster$nonrefs;
typedef struct _jc_java_awt_dnd_DnDEventMulticaster$object	_jc_java_awt_dnd_DnDEventMulticaster$object;

typedef const struct _jc_java_awt_dnd_DnDEventMulticaster$vmethods	_jc_java_awt_dnd_DnDEventMulticaster$vmethods;
typedef const struct _jc_java_awt_dnd_DnDEventMulticaster$vtable	_jc_java_awt_dnd_DnDEventMulticaster$vtable;
typedef const struct _jc_java_awt_dnd_DnDEventMulticaster$vtype	_jc_java_awt_dnd_DnDEventMulticaster$vtype;

// Constructors
extern void _jc_java_awt_dnd_DnDEventMulticaster$method$_init$5c41d1f818e19ce0(_jc_env *, struct _jc_java_awt_dnd_DnDEventMulticaster$object *, struct _jc_object *, struct _jc_object *);

// Static methods
extern struct _jc_object *_jc_java_awt_dnd_DnDEventMulticaster$method$add$3316b562908161ab(_jc_env *, struct _jc_object *, struct _jc_object *);
extern struct _jc_object *_jc_java_awt_dnd_DnDEventMulticaster$method$add$ce25761d5c58c0a4(_jc_env *, struct _jc_object *, struct _jc_object *);
extern struct _jc_object *_jc_java_awt_dnd_DnDEventMulticaster$method$remove$a165e5627f45099a(_jc_env *, struct _jc_object *, struct _jc_object *);
extern struct _jc_object *_jc_java_awt_dnd_DnDEventMulticaster$method$remove$7fc463c74079a2b6(_jc_env *, struct _jc_object *, struct _jc_object *);

// Virtual methods structure
struct _jc_java_awt_dnd_DnDEventMulticaster$vmethods {
};

// Vtable
struct _jc_java_awt_dnd_DnDEventMulticaster$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AWTEventMulticaster$vmethods	java_awt_AWTEventMulticaster;
	_jc_java_awt_dnd_DnDEventMulticaster$vmethods	java_awt_dnd_DnDEventMulticaster;
};

// Vtype
struct _jc_java_awt_dnd_DnDEventMulticaster$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DnDEventMulticaster$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DnDEventMulticaster$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DnDEventMulticaster$refs {
    _jc_java_awt_dnd_DnDEventMulticaster$sub_refs	java_awt_dnd_DnDEventMulticaster;
    _jc_java_awt_AWTEventMulticaster$sub_refs	java_awt_AWTEventMulticaster;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DnDEventMulticaster$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DnDEventMulticaster$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AWTEventMulticaster$sub_nonrefs	java_awt_AWTEventMulticaster;
    _jc_java_awt_dnd_DnDEventMulticaster$sub_nonrefs	java_awt_dnd_DnDEventMulticaster;
};

// Object instance structure
struct _jc_java_awt_dnd_DnDEventMulticaster$object {
	_jc_java_awt_dnd_DnDEventMulticaster$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DnDEventMulticaster$vtype	*vtype;
	_jc_java_awt_dnd_DnDEventMulticaster$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DnDEventMulticaster$vtype _jc_java_awt_dnd_DnDEventMulticaster$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DnDEventMulticaster, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DnDEventMulticaster$class_object;

#endif	/* _JC_java_awt_dnd_DnDEventMulticaster_H_ */

==> jc-1.4.6.tar.gz: java/awt/dnd/DnDEventMulticaster.h <==
// class java.awt.dnd.DnDEventMulticaster

// class file dependencies
// @dep_class 36cab3420c6eb6e6 java_awt_AWTEventMulticaster
// @dep_class 4d3f307f23762559 java_awt_dnd_DnDEventMulticaster
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_AWTEventMulticaster

#include "java/awt/AWTEventMulticaster.h"

#ifndef _JC_java_awt_dnd_DnDEventMulticaster_H_
#define _JC_java_awt_dnd_DnDEventMulticaster_H_

// Forward structure declarations
struct _jc_java_awt_dnd_DragSourceListener$object;
struct _jc_java_awt_dnd_DragSourceMotionListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_EventListener$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DnDEventMulticaster$sub_refs	_jc_java_awt_dnd_DnDEventMulticaster$sub_refs;
typedef struct _jc_java_awt_dnd_DnDEventMulticaster$sub_nonrefs	_jc_java_awt_dnd_DnDEventMulticaster$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DnDEventMulticaster$refs	_jc_java_awt_dnd_DnDEventMulticaster$refs;
typedef struct _jc_java_awt_dnd_DnDEventMulticaster$nonrefs	_jc_java_awt_dnd_DnDEventMulticaster$nonrefs;
typedef struct _jc_java_awt_dnd_DnDEventMulticaster$object	_jc_java_awt_dnd_DnDEventMulticaster$object;

typedef const struct _jc_java_awt_dnd_DnDEventMulticaster$vmethods	_jc_java_awt_dnd_DnDEventMulticaster$vmethods;
typedef const struct _jc_java_awt_dnd_DnDEventMulticaster$vtable	_jc_java_awt_dnd_DnDEventMulticaster$vtable;
typedef const struct _jc_java_awt_dnd_DnDEventMulticaster$vtype	_jc_java_awt_dnd_DnDEventMulticaster$vtype;

// Constructors
extern void _jc_java_awt_dnd_DnDEventMulticaster$method$_init$5c41d1f818e19ce0(_jc_env *, struct _jc_java_awt_dnd_DnDEventMulticaster$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_java_awt_dnd_DnDEventMulticaster$method$add$3316b562908161ab(_jc_env *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_awt_dnd_DnDEventMulticaster$method$add$ce25761d5c58c0a4(_jc_env *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_awt_dnd_DnDEventMulticaster$method$remove$a165e5627f45099a(_jc_env *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_awt_dnd_DnDEventMulticaster$method$remove$7fc463c74079a2b6(_jc_env *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_dnd_DnDEventMulticaster$vmethods {
};

// Vtable
struct _jc_java_awt_dnd_DnDEventMulticaster$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AWTEventMulticaster$vmethods	java_awt_AWTEventMulticaster;
	_jc_java_awt_dnd_DnDEventMulticaster$vmethods	java_awt_dnd_DnDEventMulticaster;
};

// Vtype
struct _jc_java_awt_dnd_DnDEventMulticaster$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DnDEventMulticaster$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DnDEventMulticaster$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DnDEventMulticaster$refs {
    _jc_java_awt_dnd_DnDEventMulticaster$sub_refs	java_awt_dnd_DnDEventMulticaster;
    _jc_java_awt_AWTEventMulticaster$sub_refs	java_awt_AWTEventMulticaster;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DnDEventMulticaster$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DnDEventMulticaster$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AWTEventMulticaster$sub_nonrefs	java_awt_AWTEventMulticaster;
    _jc_java_awt_dnd_DnDEventMulticaster$sub_nonrefs	java_awt_dnd_DnDEventMulticaster;
};

// Object instance structure
struct _jc_java_awt_dnd_DnDEventMulticaster$object {
	_jc_java_awt_dnd_DnDEventMulticaster$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DnDEventMulticaster$vtype	*vtype;
	_jc_java_awt_dnd_DnDEventMulticaster$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DnDEventMulticaster$vtype _jc_java_awt_dnd_DnDEventMulticaster$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DnDEventMulticaster, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DnDEventMulticaster$class_object;

#endif	/* _JC_java_awt_dnd_DnDEventMulticaster_H_ */
